# For settings.json

Available themes: `light`, `dark`, `tokyo-night`, `tokyo-night-storm`, `tokyo-night-light`, `night-owl`, `night-owl-light`, `synthwave-84`, `one-dark-pro`

- light
- dark
- tokyo-night
- tokyo-night-storm
- tokyo-night-light
- night-owl
- night-owl-light
- synthwave-84
- one-dark-pro

Available metricsCollectionMode: `on-demand` (only collect when popup open), `persistent` (collect continuously in background, uses more memory (obviously)

Example settings.json:
```json
{
  "theme": "dark",
  "metricsCollectionMode": "on-demand"
}
```
